@@ -1,8 +1,8 @@
 #!/usr/bin/python3
 #
 #    test-ufw.py quality assurance test script for ufw
-#    Copyright (C) 2011-2021 Canonical Ltd.
-#    Author: Jamie Strandboge <jdstrand@ubuntu.com>
+#    Copyright (C) 2011-2012 Canonical Ltd.
+#    Author: Jamie Strandboge <jamie@canonical.com>
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -79,10 +79,10 @@ class UfwCommon(unittest.TestCase):
 
     def _flush_firewall(self):
         '''Flush firewall'''
-        if os.path.exists('/usr/lib/ufw/ufw-init'):
-            cmd(['/usr/lib/ufw/ufw-init', 'flush-all'])
+        if os.path.exists('/lib/ufw/ufw-init'):
+            cmd(['/lib/ufw/ufw-init', 'flush-all'])
         else:
-            # based on '/usr/lib/ufw/ufw-init flush-all'
+            # based on '/lib/ufw/ufw-init flush-all'
             for exe in ['iptables', 'ip6tables']:
                 cmd([exe, '-F'])
                 cmd([exe, '-X'])
